[][src]Struct avocado::coll::InsertManyErrorContext

pub struct InsertManyErrorContext<T>(_);

This additional context info may be associated with an error when Collection::insert_many() fails to insert some of the documents or some of the inserted IDs fail to deserialize. It is not, however, returned when the insertion isn't even attempted due to another error, e.g. when the documents to be inserted fail to serialize as BSON upfront.