[−][src]Enum avocado::error::ErrorKind
A structured, "machine-readable" error kind.
Variants
JsonTranscodingThere was an error converting between JSON and a strongly-typed value.
BsonEncodingThere was an error converting a strongly-typed value to BSON.
BsonDecodingThere was an error converting BSON to a strongly-typed value.
BsonNumberReprThis numerical value can't be represented in BSON (because,
for example, it exceeds the range of i64)
MissingDocumentFieldA field with the specified key was not found in the BSON document.
IllTypedDocumentFieldA field with the specified key was found in the BSON document, but it was of an unexpected type.
MissingIdOne or more ID fields (e.g. _id in an entity document or
inserted_id in a MongoDB response) could not be found.
ObjectIdGenerationAn ObjectId could not be generated.
MongoDbErrorAn error that comes from the MongoDB driver.
MongoDbWriteExceptionAn error coming from MongoDB, related to a single write operation.
MongoDbBulkWriteExceptionAn error coming from MongoDB, related to a bulk write operation.
IntConversionUnderflowAn attempt was made to convert a negative integer to a usize.
IntConversionOverflowAn attempt was made to convert an integer that is too big to a usize.
BsonSchemaThere was an error in the BSON schema for a type.
Methods
impl ErrorKind[src]