[−][src]Enum avocado::literal::DateTimeType
Tells the $currentDate operator which type it should use for setting its fields.
let update = doc!{ "$currentDate": { "date": DateTimeType::Date, "time": DateTimeType::Timestamp, } }; assert_eq!(update, doc!{ "$currentDate": { "date": "date", "time": "timestamp", } });
Variants
Timestampthe $currentDate operator will set the field to a timestamp value.
Datethe $currentDate operator will set the field to a Date value.