[−]Struct avocado::literal::RegexOpts
Options for matching text against a regular expression.
Useful with the $regex operator. E.g.:
let query = doc!{ "name": { "$regex": "^Foo", "$options": RegexOpts::LINE_ANCHOR | RegexOpts::IGNORE_CASE, }, "address": { "$regex": ".* street$", "$options": RegexOpts::default(), }, }; assert_eq!(query, doc!{ "name": { "$regex": "^Foo", "$options": "im", }, "address": { "$regex": ".* street$", "$options": "", }, });
Methods
impl RegexOpts
pub const IGNORE_CASE: RegexOpts
Case insensitive matching.
pub const LINE_ANCHOR: RegexOpts
^ and $ match the beginning and the end of lines, not the whole string.
pub const EXTENDED: RegexOpts
"extended" syntax, allows embedded whitespace and #-comments
pub const DOT_NEWLINE: RegexOpts
The . character matches newlines too.
pub const fn empty() -> RegexOpts
Returns an empty set of flags
pub const fn all() -> RegexOpts
Returns the set containing all flags.
pub const fn bits(&self) -> u8
Returns the raw value of the flags currently stored.
pub fn from_bits(bits: u8) -> Option<RegexOpts>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
pub const fn from_bits_truncate(bits: u8) -> RegexOpts
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
pub const fn is_empty(&self) -> bool
Returns true if no flags are currently stored.
pub const fn is_all(&self) -> bool
Returns true if all flags are currently set.
pub const fn intersects(&self, other: RegexOpts) -> bool
Returns true if there are flags common to both self and other.
pub const fn contains(&self, other: RegexOpts) -> bool
Returns true all of the flags in other are contained within self.
pub fn insert(&mut self, other: RegexOpts)
Inserts the specified flags in-place.
pub fn remove(&mut self, other: RegexOpts)
Removes the specified flags in-place.
pub fn toggle(&mut self, other: RegexOpts)
Toggles the specified flags in-place.
pub fn set(&mut self, other: RegexOpts, value: bool)
Inserts or removes the specified flags depending on the passed value.