[][src]Enum avocado::error::ErrorKind

pub enum ErrorKind {
    JsonTranscoding,
    BsonEncoding,
    BsonDecoding,
    BsonNumberRepr,
    MissingDocumentField,
    IllTypedDocumentField,
    MissingId,
    ObjectIdGeneration,
    MongoDbError,
    MongoDbWriteException,
    MongoDbBulkWriteException,
    IntConversionUnderflow,
    IntConversionOverflow,
    BsonSchema,
}

A structured, "machine-readable" error kind.

Variants

JsonTranscoding

There was an error converting between JSON and a strongly-typed value.

BsonEncoding

There was an error converting a strongly-typed value to BSON.

BsonDecoding

There was an error converting BSON to a strongly-typed value.

BsonNumberRepr

This numerical value can't be represented in BSON (because, for example, it exceeds the range of i64)

MissingDocumentField

A field with the specified key was not found in the BSON document.

IllTypedDocumentField

A field with the specified key was found in the BSON document, but it was of an unexpected type.

MissingId

One or more ID fields (e.g. _id in an entity document or inserted_id in a MongoDB response) could not be found.

ObjectIdGeneration

An ObjectId could not be generated.

MongoDbError

An error that comes from the MongoDB driver.

MongoDbWriteException

An error coming from MongoDB, related to a single write operation.

MongoDbBulkWriteException

An error coming from MongoDB, related to a bulk write operation.

IntConversionUnderflow

An attempt was made to convert a negative integer to a usize.

IntConversionOverflow

An attempt was made to convert an integer that is too big to a usize.

BsonSchema

There was an error in the BSON schema for a type.

Methods

impl ErrorKind[src]

pub fn as_str(self) -> &'static str[src]

Returns a human-readable error description for this kind.